@@ -687,9 +687,9 @@ def getmap(data):
     max.append(center[1]+step[1])
     max.append(center[2]+step[2])
 
-    data = array(data, 'f').reshape(pts[2], pts[1], pts[0])
+    data = array(data, 'f').reshape(int(pts[2]), int(pts[1]), int(pts[0]))
 
-    data = data.reshape(pts[2], pts[1], pts[0])
+    data = data.reshape(int(pts[2]), int(pts[1]), int(pts[0]))
     return { "values" : data, "spacing" : spacing, 'pts': pts, 'center' : center, 'min' : min, 'max' : max}
     
 
@@ -700,7 +700,6 @@ def getpoints(mapdata, coords=None, distance=None):
     max = mapdata['max']
     spacing = mapdata['spacing']
     pts = mapdata['pts']
-    harvesting = []
     
     if not distance:
         distace = 1.0 # default 1A distance scanning
@@ -723,24 +722,20 @@ def getpoints(mapdata, coords=None, distance=None):
 
                 for x_ofs in range(-pt_scan, pt_scan+1): 
                     x = x_pt + x_ofs
-                    if x < 0 :
-                        harvesting.append(0)
+                    if x < 0 or x >= pts[0]:
                         break
                     for y_ofs in range(-pt_scan, pt_scan+1): 
                         y = y_pt + y_ofs
-                        if y < 0 :
-                            harvesting.append(0)
+                        if y < 0 or y >= pts[1]:
                             break
                         for z_ofs in range(-pt_scan, pt_scan+1): 
                             z = z_pt + z_ofs
-                            if z < 0 :
-                                harvesting.append(0)
+                            if z < 0 or z >= pts[2]:
                                 break
-                            harvesting.append( data[z,y,x] )
                             if data[z,y,x] < best:
                                 best = data[z,y,x]
-            if DEBUG: print(" %d pts [ best: %2.2f ]" % (len(harvesting), best), end=' ')
-            return harvesting, best
+            if DEBUG: print(" in getpoints, best: %2.2f" % best, end=' ')
+            return best
     return False
 
 
@@ -1191,7 +1186,7 @@ if grid :
 
     if not QUIET: print("\n water grid score results [ map: %s ] " % (opts['-m']))
     for w in watoms:
-        harvest, affinity = getpoints(grid, coord(w), distance = 1.0) # angstroms
+        affinity = getpoints(grid, coord(w), distance = 1.0) # angstroms
         #WAFFINITY_STRONG = -0.45 
         #WAFFINITY_WEAK   = -0.3
 
